SvgCacheKey class

A SvgTheme aware cache key.

The theme must be part of the cache key to ensure that otherwise similar SVGs get cached separately.

Annotations

Constructors

SvgCacheKey({required Object keyData, required ColorMapper? colorMapper, SvgTheme? theme})
See SvgCacheKey.
const

Properties

colorMapper → ColorMapper?
The color mapper for the SVG, if any.
final
hashCode → int
The hash code for this object.
no setteroverride
keyData → Object
The other key data for the SVG.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → SvgTheme?
The theme for this cached SVG.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override